vfbLib.parsers.glyph.GlyphParser
================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphParser.__init__
      ~GlyphParser.parse
      ~GlyphParser.parse_binary
      ~GlyphParser.parse_components
      ~GlyphParser.parse_guides
      ~GlyphParser.parse_hex
      ~GlyphParser.parse_hints
      ~GlyphParser.parse_instructions
      ~GlyphParser.parse_kerning
      ~GlyphParser.parse_metrics
      ~GlyphParser.parse_outlines
      ~GlyphParser.read_double
      ~GlyphParser.read_doubles
      ~GlyphParser.read_float
      ~GlyphParser.read_floats
      ~GlyphParser.read_int16
      ~GlyphParser.read_int32
      ~GlyphParser.read_int8
      ~GlyphParser.read_str
      ~GlyphParser.read_str_all
      ~GlyphParser.read_uint16
      ~GlyphParser.read_uint32
      ~GlyphParser.read_uint8
      ~GlyphParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphParser.encoding
      ~GlyphParser.master_count
      ~GlyphParser.stream
      ~GlyphParser.ttStemsH_count
      ~GlyphParser.ttStemsV_count
   
   